CsvHandler class

Helper class to load and save the data in csv format.

Constructors

CsvHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
loading ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ FibuSettings
getter/setter pair

Methods

detectEOL(String fileContent) → String
load({Book? book, FibuSettings? conf, String data = ""}) → void
load a book.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save({Book? book, KontoPlan? kpl, Journal? jrl, FibuSettings? conf}) → void
save a book.
toString() → String
A string representation of this object.
inherited
unixEOL(String fileContent) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited