nohfibu
library
Classes
Book
Book class, holds an accountplan and a journal.
CLIInputProvider
CLI implementation of the InputProvider
Represents one line in an extract journal.
Fibu
Launcher for the accounting analysis
InputProvider
Abstract class to gather inputs (used for both CLI and GUI)
Journal
This class hold a list of lines, each caracterising an entry in an accounting journal.
JrlLine
Represents one line in an accounting journal.
Konto
one account .
Represents an account in the accounting system.
Each account has properties such as a name, valuta (amount), and a budget.
KontoPlan
Represents the account plan in the accounting system.
It organizes accounts and allows for tree-like structures of accounts.
Functions
cur2sym (String name )
→ String
Converts currency code to its corresponding symbol.
Supported currencies include EUR, GBP, USD, YEN, and LIR.
Defaults to € if the currency is unrecognized.