CLIInteraction class

The default implementation of UserInteractionon CLI level

Implemented types

Constructors

CLIInteraction()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promptForAccountSelection(String message, List<String> options) → Future<String>
override
promptForTextInput(String message, {String defaultValue = ""}) → Future<String>
override
promptForValueInput(String message, {int defaultValue = 0}) → Future<int>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited